@@ -34,7 +34,7 @@ def evaluate(x_in, params=[]):
     '''
 
     # provide your system model and pass x_in as an argument
-    total_cost = es.run_ESTD_UQ([x_in, params[0]['results dir']], params[0]['AMPL path'])
+    total_cost = es.run_ESTD_UQ([x_in, params[0]['results dir']], params[0]['AMPL path'], params[0]['gwp limit'])
 
     # return the objectives
     return [total_cost]
